@@ -100,6 +100,17 @@ static const QString s_test_subdir{QStringLiteral("kconfigtest_subdir/")};
 static const QString s_kconfig_test_subdir(s_test_subdir + QLatin1String("kconfigtest"));
 static const QString s_kconfig_test_illegal_object_path(s_test_subdir + QLatin1String("kconfig-test"));
 
+static const std::chrono::nanoseconds s_nanoseconds_entry{1};
+static const std::chrono::microseconds s_microseconds_entry{2};
+static const std::chrono::milliseconds s_milliseconds_entry{3};
+static const std::chrono::seconds s_seconds_entry{4};
+static const std::chrono::minutes s_minutes_entry{5};
+static const std::chrono::hours s_hours_entry{6};
+static const std::chrono::days s_days_entry{7};
+static const std::chrono::weeks s_weeks_entry{8};
+static const std::chrono::years s_years_entry{9};
+static const std::chrono::months s_months_entry{10};
+
 #ifndef Q_OS_WIN
 void initLocale()
 {
@@ -218,6 +229,18 @@ void KConfigTest::initTestCase()
     cg.writeEntry("flags-bit0-bit1", Flags(bit0 | bit1));
 #endif
 
+    cg = KConfigGroup(&sc, QStringLiteral("Chrono Types"));
+    cg.writeEntry("nanosecondsEntry", s_nanoseconds_entry);
+    cg.writeEntry("microsecondsEntry", s_microseconds_entry);
+    cg.writeEntry("millisecondsEntry", s_milliseconds_entry);
+    cg.writeEntry("secondsEntry", s_seconds_entry);
+    cg.writeEntry("minutesEntry", s_minutes_entry);
+    cg.writeEntry("hoursEntry", s_hours_entry);
+    cg.writeEntry("daysEntry", s_days_entry);
+    cg.writeEntry("weeksEntry", s_weeks_entry);
+    cg.writeEntry("yearsEntry", s_years_entry);
+    cg.writeEntry("monthsEntry", s_months_entry);
+
     cg = KConfigGroup(&sc, QStringLiteral("ParentGroup"));
     KConfigGroup cg1(&cg, QStringLiteral("SubGroup1"));
     cg1.writeEntry("somestring", "somevalue");
@@ -492,7 +515,7 @@ void KConfigTest::testLists()
 
     QCOMPARE(sc3.readEntry("listOfIntsEntry1"), QString::fromLatin1("1,2,3,4"));
     QList<int> expectedIntList = s_int_listentry1;
-    QVERIFY(sc3.readEntry("listOfIntsEntry1", QList<int>()) == expectedIntList);
+    QCOMPARE(sc3.readEntry("listOfIntsEntry1", QList<int>()), expectedIntList);
 
     QCOMPARE(QVariant(sc3.readEntry("variantListEntry", s_variantlist_entry)).toStringList(), QVariant(s_variantlist_entry).toStringList());
 
@@ -637,7 +660,7 @@ void KConfigTest::testEnums()
     QVERIFY(sc3.readEntry("enum-100", Ones) != Tens);
 
     QCOMPARE(sc3.readEntry("flags-bit0"), QStringLiteral("bit0"));
-    QVERIFY(sc3.readEntry("flags-bit0", Flags()) == bit0);
+    QCOMPARE(sc3.readEntry("flags-bit0", Flags()), bit0);
 
     int eid = staticMetaObject.indexOfEnumerator("Flags");
     QVERIFY(eid != -1);
@@ -645,7 +668,7 @@ void KConfigTest::testEnums()
     Flags bitfield = bit0 | bit1;
 
     QCOMPARE(sc3.readEntry("flags-bit0-bit1"), QString::fromLatin1(me.valueToKeys(bitfield)));
-    QVERIFY(sc3.readEntry("flags-bit0-bit1", Flags()) == bitfield);
+    QCOMPARE(sc3.readEntry("flags-bit0-bit1", Flags()), bitfield);
 }
 
 void KConfigTest::testEntryMap()
@@ -686,63 +709,63 @@ void KConfigTest::testInvalid()
     list << 1;
     sc3.writeEntry(QStringLiteral("badList"), list);
 
-    QVERIFY(sc3.readEntry("badList", QPoint()) == QPoint());
-    QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
-    QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
-    QVERIFY(sc3.readEntry("badList", QDate()) == QDate());
-    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
-    QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
+    QCOMPARE(sc3.readEntry("badList", QPoint()), QPoint());
+    QCOMPARE(sc3.readEntry("badList", QRect()), QRect());
+    QCOMPARE(sc3.readEntry("badList", QSize()), QSize());
+    QCOMPARE(sc3.readEntry("badList", QDate()), QDate());
+    QCOMPARE(sc3.readEntry("badList", QTime()), QTime());
+    QCOMPARE(sc3.readEntry("badList", QDateTime()), QDateTime());
 
     // 2 element list
     list << 2;
     sc3.writeEntry("badList", list);
 
-    QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
-    QVERIFY(sc3.readEntry("badList", QDate()) == QDate());
-    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
-    QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
+    QCOMPARE(sc3.readEntry("badList", QRect()), QRect());
+    QCOMPARE(sc3.readEntry("badList", QDate()), QDate());
+    QCOMPARE(sc3.readEntry("badList", QTime()), QTime());
+    QCOMPARE(sc3.readEntry("badList", QDateTime()), QDateTime());
 
     // 3 element list
     list << 303;
     sc3.writeEntry("badList", list);
 
-    QVERIFY(sc3.readEntry("badList", QPoint()) == QPoint());
-    QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
-    QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
-    QVERIFY(sc3.readEntry("badList", QDate()) == QDate()); // out of bounds
-    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
-    QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
+    QCOMPARE(sc3.readEntry("badList", QPoint()), QPoint());
+    QCOMPARE(sc3.readEntry("badList", QRect()), QRect());
+    QCOMPARE(sc3.readEntry("badList", QSize()), QSize());
+    QCOMPARE(sc3.readEntry("badList", QDate()), QDate()); // out of bounds
+    QCOMPARE(sc3.readEntry("badList", QTime()), QTime());
+    QCOMPARE(sc3.readEntry("badList", QDateTime()), QDateTime());
 
     // 4 element list
     list << 4;
     sc3.writeEntry("badList", list);
 
-    QVERIFY(sc3.readEntry("badList", QPoint()) == QPoint());
-    QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
-    QVERIFY(sc3.readEntry("badList", QDate()) == QDate());
-    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
-    QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
+    QCOMPARE(sc3.readEntry("badList", QPoint()), QPoint());
+    QCOMPARE(sc3.readEntry("badList", QSize()), QSize());
+    QCOMPARE(sc3.readEntry("badList", QDate()), QDate());
+    QCOMPARE(sc3.readEntry("badList", QTime()), QTime());
+    QCOMPARE(sc3.readEntry("badList", QDateTime()), QDateTime());
 
     // 5 element list
     list[2] = 3;
     list << 5;
     sc3.writeEntry("badList", list);
 
-    QVERIFY(sc3.readEntry("badList", QPoint()) == QPoint());
-    QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
-    QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
-    QVERIFY(sc3.readEntry("badList", QDate()) == QDate());
-    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
-    QVERIFY(sc3.readEntry("badList", QDateTime()) == QDateTime());
+    QCOMPARE(sc3.readEntry("badList", QPoint()), QPoint());
+    QCOMPARE(sc3.readEntry("badList", QRect()), QRect());
+    QCOMPARE(sc3.readEntry("badList", QSize()), QSize());
+    QCOMPARE(sc3.readEntry("badList", QDate()), QDate());
+    QCOMPARE(sc3.readEntry("badList", QTime()), QTime());
+    QCOMPARE(sc3.readEntry("badList", QDateTime()), QDateTime());
 
     // 6 element list
     list << 6;
     sc3.writeEntry("badList", list);
 
-    QVERIFY(sc3.readEntry("badList", QPoint()) == QPoint());
-    QVERIFY(sc3.readEntry("badList", QRect()) == QRect());
-    QVERIFY(sc3.readEntry("badList", QSize()) == QSize());
-    QVERIFY(sc3.readEntry("badList", QTime()) == QTime());
+    QCOMPARE(sc3.readEntry("badList", QPoint()), QPoint());
+    QCOMPARE(sc3.readEntry("badList", QRect()), QRect());
+    QCOMPARE(sc3.readEntry("badList", QSize()), QSize());
+    QCOMPARE(sc3.readEntry("badList", QTime()), QTime());
 }
 
 void KConfigTest::testChangeGroup()
@@ -1334,7 +1357,7 @@ void KConfigTest::testReparent()
 
     QVERIFY(!parent.hasGroup(name));
 
-    QVERIFY(group.entryMap() == originalMap);
+    QCOMPARE(group.entryMap(), originalMap);
 
     group.reparent(&parent); // see if it can be made a sub-group of another group
     QVERIFY(parent.hasGroup(name));
@@ -2228,6 +2251,25 @@ void KConfigTest::testKAuthorizeEnums()
     QVERIFY(!KAuthorized::authorizeAction((KAuthorized::GenericAction)0));
 }
 
+void KConfigTest::testChrono()
+{
+    using namespace std::chrono_literals;
+
+    KConfig sc2(s_kconfig_test_subdir);
+    KConfigGroup sc3(&sc2, QStringLiteral("Chrono Types"));
+
+    QCOMPARE(sc3.readEntry("nanosecondsEntry", 0ns), s_nanoseconds_entry);
+    QCOMPARE(sc3.readEntry("microsecondsEntry", 0us), s_microseconds_entry);
+    QCOMPARE(sc3.readEntry("millisecondsEntry", 0ms), s_milliseconds_entry);
+    QCOMPARE(sc3.readEntry("secondsEntry", 0s), s_seconds_entry);
+    QCOMPARE(sc3.readEntry("minutesEntry", 0min), s_minutes_entry);
+    QCOMPARE(sc3.readEntry("hoursEntry", 0h), s_hours_entry);
+    QCOMPARE(sc3.readEntry("daysEntry", std::chrono::days(0)), s_days_entry);
+    QCOMPARE(sc3.readEntry("weeksEntry", std::chrono::weeks(0)), s_weeks_entry);
+    QCOMPARE(sc3.readEntry("yearsEntry", std::chrono::years(0)), s_years_entry);
+    QCOMPARE(sc3.readEntry("monthsEntry", std::chrono::months(0)), s_months_entry);
+}
+
 void KConfigTest::testKdeglobalsVsDefault()
 {
     // Add testRestore key with global value in kdeglobals
